# !/bin/bash
# NeoKylin Software Center Client Init.

LANGUAGE=`echo $LANG`
#PS_SOFTCENTER=`ps -a |grep softCenter |awk '{print $4}'`
PS_SOFTCENTER=`ps -aux | grep softCenter | grep -v grep | awk '{print $11}'`
INIT_MY_NAME=`whoami`
INI_DATE=`ls -l --full-time /opt/softwarecenter/doc/client-config.ini |awk '{print $6 $7}'`
SC_PPID=`ps -aux | grep neokylin-software-center_start.sh | grep -v grep | awk '{print $2}'`
SC_PID=`ps -aux | grep softCenter | grep -v grep | awk '{print $2}'`

useradd_fix_for_systemd_update()
{
# for erlang-erts %pre
	if ! getent group epmd >/dev/null; then
		echo 'Creating group "epmd"'
		groupadd -r epmd
	else
		echo 'Group "epmd" already exists'
	fi
	if ! getent passwd epmd >/dev/null; then
		echo 'Creating user "epmd"'
		useradd -r -g epmd -d /tmp -s /sbin/nologin -c "Erlang Port Mapper Daemon" epmd
	else
		echo 'User "epmd" already exists'
	fi

# for rabbitmq-server %pre
	if ! getent group rabbitmq >/dev/null; then
		echo 'Creating group "rabbitmq"'
		groupadd -r rabbitmq
	else
		echo 'Group "rabbitmq" already exists'
	fi
	if ! getent passwd rabbitmq >/dev/null; then
		echo 'Creating user "rabbitmq"'
		useradd -r -g rabbitmq -d /var/lib/rabbitmq rabbitmq -s /sbin/nologin -c "RabbitMQ messaging server"
	else
		echo 'User "rabbitmq" already exists'
	fi
}

check_user()
{
	i=`cat /etc/passwd | cut -f1 -d':' | grep -w "$1" -c`
	if [ $i -le 0 ]; then
		#echo "User $1 is not in the passwd"
		return 0
	else
		return 1
	fi
}

if [ "$LANGUAGE" != "zh_CN.UTF-8" ] && [ "$LANGUAGE" != "zh_CN.utf-8" ];then
	if [ "$INIT_MY_NAME" != "root" ];then
		echo -e "\033[31m[ERROR] NeoKylin Software Center Initial Script must execute as \033[34mroot\033[0m"
		echo -e "\033[31m[ERROR] Please switch to \033[34mroot\033[31m then execute the initial script: \033[0m"
		echo
		echo -e "     /usr/share/doc/software-center/scc-init.sh "
		echo
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo -e "\033[31m[ERROR] EXIT INIT...\033[0m"
		if [ "$SC_PPID" != "" ];then
			#kill -9 `echo $SC_PPID`
			echo
		fi
		notify-send -t 20000 "Please switch to root then execute :" "/usr/share/doc/software-center/scc-init.sh"
		notify-send -t 5000 "NeoKylin Software Center Init FAILED ! " "The current user $INIT_MY_NAME is not in the sudoers file." 
		sleep 2
		exit
	fi
	if [ "$PS_SOFTCENTER" == "/usr/sbin/softCenter" ] ; then
		echo -e "\033[31m[ERROR] softCenter still running, you can not exec this script.\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo -e "\033[31m[ERROR] EXIT\033[0m"
		sleep 3
		exit
	fi
	echo -e "\033[34m[INFO] Software Center Client Init START\033[0m"
	echo
	echo -e "\033[34m[INFO] configuring rabbitmq-server ...\033[0m"
	useradd_fix_for_systemd_update
	systemctl restart rabbitmq-server
	systemctl enable rabbitmq-server
	echo -e "\033[34m[INFO] checking rabbitmq-server ...\033[0m"
	RABBITMQ_SERVER_STATUS=`systemctl list-units --all --type=service |grep rabbitmq-server |awk '{print $4}'`
	if [ "$RABBITMQ_SERVER_STATUS" != "running" ]; then
		echo -e "\033[34m[WARNING] rabbitmq-server is\033[0m $RABBITMQ_SERVER_STATUS"
		echo -e "\033[34m[WARNING] try to restart service rabbitmq-server ...\033[0m"
		if [ "`ls -ld /var/lib/rabbitmq |awk '{print $3}'`" != "rabbitmq" ] || [ "`ls -ld /var/lib/rabbitmq |awk '{print $4}'`" != "rabbitmq" ] || [ "`ls -ld /var/log/rabbitmq |awk '{print $3}'`" != "rabbitmq" ] || [ "`ls -ld /var/log/rabbitmq |awk '{print $4}'`" != "rabbitmq" ]; then
			check_user rabbitmq
			if [ $? -eq 0 ]; then
				useradd rabbitmq
			fi
			chown -R rabbitmq:rabbitmq /var/lib/rabbitmq /var/log/rabbitmq
		fi
		systemctl restart rabbitmq-server
		RABBITMQ_SERVER_STATUS=`systemctl list-units --all --type=service |grep rabbitmq-server |awk '{print $4}'`
		if [ $RABBITMQ_SERVER_STATUS != "running" ]; then
			echo -e "\033[31m[ERROR] EXIT because rabbitmq-server configure failed\033[0m"
			rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
			echo "ConfigError : rabbitmq-server failed to start" > /opt/softwarecenter/.SOFT_FLAG
			exit
		fi
	fi
	echo -e "\033[34m[INFO] rabbitmq-server is\033[0m $RABBITMQ_SERVER_STATUS"
	echo -e "\033[34m[INFO] configuring rabbitmq-server user ...\033[0m"
	RABBITMQ_USER_SCS=`rabbitmqctl list_users |grep scs |awk '{print $1}'`
	if [ "$RABBITMQ_USER_SCS" == "scs" ] ; then
		rabbitmqctl delete_user scs
	fi
	rabbitmqctl add_user scs qwe123
	rabbitmqctl set_user_tags scs administrator
	rabbitmqctl set_permissions -p / scs ".*" ".*" ".*"
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] rabbitmq-server user config failed!\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : rabbitmq-server user config failed" > /opt/softwarecenter/.SOFT_FLAG
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] configure rabbitmq-server success!\033[0m"
	fi
	echo
	echo -e "\033[34m[INFO] initial sqlite database ...\033[0m"
	/usr/sbin/packageinfo
	chmod 777 /opt/softwarecenter/db/server_software.db
	sqlite3 /opt/softwarecenter/db/server_software.db "delete from softwares"
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] initial sqlite database failed!\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : initial sqlite database failed" > /opt/softwarecenter/.SOFT_FLAG
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] initial sqlite database success!\033[0m"
	fi
	echo
	echo -e "\033[34m[INFO] checking firewalld service ...\033[0m"
	FIREWALLD_STATUS=`systemctl list-units --all --type=service |grep firewalld |awk '{print $4}'`
	if [ "$FIREWALLD_STATUS" == "running" ] ; then
		echo -e "\033[34m[INFO] firewalld is\033[0m $FIREWALLD_STATUS"
		echo -e "\033[34m[INFO] configure firewalld ...\033[0m"
		firewall-cmd --permanent --add-port={5672/tcp,5672/udp}
		firewall-cmd --reload
	else
		echo -e "\033[34m[INFO] stop & disable firewalld ...\033[0m"
		systemctl disable firewalld
		systemctl stop firewalld
	fi
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] configure firewalld service failed!\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : configure firewalld service failed" > /opt/softwarecenter/.SOFT_FLAG
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] configure firewalld service success!\033[0m"
	fi
	echo
	echo -e "\033[34m[INFO] Software Center Client Init END\033[0m"
	echo
	echo -e "\033[34m[INFO] INIT END...\033[0m"
	echo $INI_DATE > /opt/softwarecenter/.SOFTINI_DATE_ORIG
	sleep 3
else
	if [ "$INIT_MY_NAME" != "root" ];then
		echo -e "\033[31m[ERROR] 中标麒麟软件中心初始化失败！\033[0m"
		echo -e "\033[31m[ERROR] 请在终端中切换到 \033[34mroot\033[31m 用户再执行中标麒麟软件中心的初始化脚本：\033[0m"
		echo
		echo -e "     /usr/share/doc/software-center/scc-init.sh "
		echo
		echo -e "\033[31m[ERROR] 中标麒麟软件中心初始化脚本 退出...\033[0m"
		if [ "$SC_PPID" != "" ];then
			#kill -9 `echo $SC_PPID`
			echo
		fi
		notify-send -t 20000 "请在终端切换到 root 用户再执行:" "/usr/share/doc/software-center/scc-init.sh"
		notify-send -t 5000 "中标麒麟软件中心初始化失败! " "当前用户 $INIT_MY_NAME 可能不在 sudoers 文件中" 
		sleep 2
		exit
	fi
	if [ "$PS_SOFTCENTER" == "/usr/sbin/softCenter" ] ; then
		echo -e "\033[31m[ERROR] 中标麒麟软件中心正在运行，此时您不能执行软件中心初始化程序！\033[0m"
		echo -e "\033[31m[ERROR] 本初始化程序将自动退出...\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		sleep 3
		exit
	fi
	echo -e "\033[34m[INFO] 您看到此内容则表明:\033[0m"
	echo -e "\033[34m[INFO]         1，您可能是首次打开中标麒麟软件中心\033[0m"
	echo -e "\033[34m[INFO]         2，您可能最近更新过中标麒麟软件中心\033[0m"
	echo -e "\033[34m[INFO]         3，您可能最近修改过中标麒麟软件中心的配置文件\033[0m"
	echo
	echo -e "\033[34m[INFO] 正在执行中标麒麟软件中心的初始化程序...\033[0m"
	echo -e "\033[34m[INFO] 请耐心等待...\033[0m"
	echo
	echo -e "\033[34m[INFO] 通信服务配置...\033[0m"
	useradd_fix_for_systemd_update
	systemctl restart rabbitmq-server
	systemctl enable rabbitmq-server
	echo -e "\033[34m[INFO] 通信服务状态检测...\033[0m"
	RABBITMQ_SERVER_STATUS=`systemctl list-units --all --type=service |grep rabbitmq-server |awk '{print $4}'`
	if [ "$RABBITMQ_SERVER_STATUS" != "running" ]; then
		echo -e "\033[34m[WARNING] 通信服务状态为: \033[0m $RABBITMQ_SERVER_STATUS"
		echo -e "\033[34m[WARNING] 正在尝试重启通信服务...\033[0m"
		if [ "`ls -ld /var/lib/rabbitmq |awk '{print $3}'`" != "rabbitmq" ] || [ "`ls -ld /var/lib/rabbitmq |awk '{print $4}'`" != "rabbitmq" ] || [ "`ls -ld /var/log/rabbitmq |awk '{print $3}'`" != "rabbitmq" ] || [ "`ls -ld /var/log/rabbitmq |awk '{print $4}'`" != "rabbitmq" ]; then
			check_user rabbitmq
			if [ $? -eq 0 ]; then
				useradd rabbitmq
			fi
			chown -R rabbitmq:rabbitmq /var/lib/rabbitmq /var/log/rabbitmq
		fi
		systemctl restart rabbitmq-server
		RABBITMQ_SERVER_STATUS=`systemctl list-units --all --type=service |grep rabbitmq-server |awk '{print $4}'`
		if [ $RABBITMQ_SERVER_STATUS != "running" ]; then
			echo -e "\033[31m[ERROR] 故障！！！通信服务重启失败！\033[0m"
			rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
			echo "ConfigError : 通信服务启动失败" > /opt/softwarecenter/.SOFT_FLAG
			echo
			echo -e "\033[31m[ERROR] 请联系您的系统管理员或运维人员，待故障排除后再使用中标麒麟软件中心。\033[0m"
			echo
			sleep 5
			exit
		fi
	fi
	echo -e "\033[34m[INFO] 通信服务状态为: \033[0m$RABBITMQ_SERVER_STATUS"
	echo -e "\033[34m[INFO] 通信服务后台用户配置...\033[0m"
	RABBITMQ_USER_SCS=`rabbitmqctl list_users |grep scs |awk '{print $1}'`
	if [ "$RABBITMQ_USER_SCS" == "scs" ] ; then
		rabbitmqctl delete_user scs
	fi
	rabbitmqctl add_user scs qwe123
	rabbitmqctl set_user_tags scs administrator
	rabbitmqctl set_permissions -p / scs ".*" ".*" ".*"
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] 通信服务后台用户配置失败！ 故障！！！\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : 通信服务后台用户配置失败" > /opt/softwarecenter/.SOFT_FLAG
		echo -e "\033[31m[ERROR] 请联系您的系统管理员或运维人员，待故障排除后再使用中标麒麟软件中心。\033[0m"
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] 通信服务配置完成。\033[0m"
	fi
	echo
	echo -e "\033[34m[INFO] 数据库初始化...\033[0m"
	/usr/sbin/packageinfo
	chmod 777 /opt/softwarecenter/db/server_software.db
	sqlite3 /opt/softwarecenter/db/server_software.db "delete from softwares"
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] 数据库初始化失败！ 故障！！！\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : 数据库初始化失败" > /opt/softwarecenter/.SOFT_FLAG
		echo -e "\033[31m[ERROR] 请联系您的系统管理员或运维人员，待故障排除后再使用中标麒麟软件中心。\033[0m"
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] 数据库初始化完成。\033[0m"
	fi
	echo
	echo -e "\033[34m[INFO] 防火墙服务状态检测...\033[0m"
	FIREWALLD_STATUS=`systemctl list-units --all --type=service |grep firewalld |awk '{print $4}'`
	if [ "$FIREWALLD_STATUS" == "running" ] ; then
		echo -e "\033[34m[INFO] 防火墙服务状态为: \033[0m$FIREWALLD_STATUS"
		echo -e "\033[34m[INFO] 防火墙通信端口设置...\033[0m"
		firewall-cmd --permanent --add-port={5672/tcp,5672/udp}
		firewall-cmd --reload
	else
		echo -e "\033[34m[INFO] 防火墙服务将被禁用...\033[0m"
		systemctl disable firewalld
		systemctl stop firewalld
	fi
	if [ "`echo $?`" != "0" ]; then
		echo -e "\033[31m[ERROR] 防火墙服务配置失败！ 故障！！！\033[0m"
		rm -rf /opt/softwarecenter/.SOFTINI_DATE_ORIG
		echo "ConfigError : 防火墙服务配置失败" > /opt/softwarecenter/.SOFT_FLAG
		echo -e "\033[31m[ERROR] 请联系您的系统管理员或运维人员，待故障排除后再使用中标麒麟软件中心。\033[0m"
		echo
		sleep 5
		exit
	else
		echo -e "\033[34m[INFO] 防火墙服务配置完成。\033[0m"
	fi
	echo $INI_DATE > /opt/softwarecenter/.SOFTINI_DATE_ORIG
	echo
	echo -e "\033[34m[INFO] 初始化完成。\033[0m"
	echo -e "\033[34m[INFO] 初始化程序 即将退出...\033[0m"
	echo
#	echo -e "\033[34m[INFO] 随后将启动中标麒麟软件中心...\033[0m"
	sleep 3
fi
